Python: module ichorORM.WhereClause

ichorORM.WhereClause | index

`Copyright (c) 2016-2018 Timothy Savannah
Licensed under the terms of the Lesser GNU Lesser General Public License version 2.1
license can be found at https://raw.githubusercontent.com/kata198/ichorORM/master/LICENSE
WhereClause - type to represent a WHERE clause and related`

Classes
`` |  | builtins.object WhereClause
class WhereClause(builtins.object)
`` | `WhereClause - Construct a "Where" clause in one of several forms psycopg2 understands`
| Static methods defined here: fromFieldValuesDictParam(fieldValues, joinBy='AND') `fromFieldValuesDictParam - Get a WHERE clause for dict-param input @param fieldValues <dict> fieldName : fieldVaulue @param joinBy <str> WHERE_AND or WHERE_OR @return String ready to be used for dict params` fromFieldValuesDirect(fieldValues, joinBy='AND') `fromFieldValuesDirect - Get a WHERE clause joining fieldValues with AND/OR @param fieldValues <dict> fieldName : fieldValue @param joinBy <str> - WHERE_AND or WHERE_OR @return String of where clause assembled from above` fromFieldValuesParam(fieldValues, joinBy='AND') `fromFieldValuesParam - Get a WHERE clause ready for paramertized input @param fieldValues <dict> fieldName : fieldValue @param joinBy <str> WHERE_AND or WHERE_OR @return String ready to be used for parameterization` Data descriptors defined here: __dict__ `dictionary for instance variables (if defined)` __weakref__ `list of weak references to the object (if defined)`

Data
`` |  | WHERE_AND = 'AND' WHERE_OR = 'OR' __all__ = ('WHERE_AND', 'WHERE_OR', 'WhereClause')